==> metview_5.7.5.orig.tar.xz: metview-5.7.5/mir/src/mir/packing/SecondOrder.h <==
/*
 * (C) Copyright 1996- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */

/// @author Baudouin Raoult
/// @author Pedro Maciel
/// @date Apr 2015


#ifndef SecondOrder_H
#define SecondOrder_H


#include "mir/packing/Packer.h"

namespace mir {
namespace packing {


class SecondOrder : public Packer {
  public:

    // -- Exceptions
    // None

    // -- Contructors

    SecondOrder(const std::string &name);

    // -- Destructor

    virtual ~SecondOrder(); // Change to virtual if base class

    // -- Convertors
    // None

    // -- Operators
    // None

    // -- Methods

    // -- Overridden methods
    // None

    // -- Class members
    // None

    // -- Class methods


  protected:

    // -- Members

    // -- Methods


    virtual void print(std::ostream &) const; // Change to virtual if base class

    // -- Overridden methods
    // None

    // -- Class members
    // None

    // -- Class methods
    // None

  private:

    // No copy allowed

    SecondOrder(const SecondOrder &);
    SecondOrder &operator=(const SecondOrder &);

    // -- Members
    // None

    // -- Methods

    // -- Overridden methods
    // None

    // -- Class members
    // None

    // -- Class methods

    virtual void fill(grib_info&, const repres::Representation& ) const;



    // -- Friends



};


}  // namespace packing
}  // namespace mir
#endif

==> metview_5.10.2.orig.tar.xz: metview-5.10.2/mir/src/mir/packing/SecondOrder.h <==
/*
 * (C) Copyright 1996- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 *
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */


#ifndef mir_packing_SecondOrder_h
#define mir_packing_SecondOrder_h

#include "mir/packing/Packer.h"


namespace mir {
namespace packing {


class SecondOrder : public Packer {
public:
    // -- Types
    // None

    // -- Exceptions
    // None

    // -- Constructors

    using Packer::Packer;

    // -- Destructor

    virtual ~SecondOrder();

    // -- Convertors
    // None

    // -- Operators
    // None

    // -- Methods
    // None

    // -- Overridden methods
    // None

    // -- Class members
    // None

    // -- Class methods
    // None

protected:
    // -- Members
    // None

    // -- Methods

    bool check(const repres::Representation&) const;

    // -- Overridden methods
    // None

    // -- Class members
    // None

    // -- Class methods
    // None

private:
    // -- Members
    // None

    // -- Methods

    virtual void print(std::ostream&) const;
    virtual void fill(grib_info&, const repres::Representation&) const;
    virtual std::string type(const repres::Representation*) const;

    // -- Overridden methods
    // None

    // -- Class members
    // None

    // -- Class methods
    // None

    // -- Friends
    // None
};


}  // namespace packing
}  // namespace mir


#endif
